@@ -1,10 +1,13 @@
 /*
- * Copyright (c) 2005 QUALCOMM Incorporated.  All rights reserved.
+ * Copyright (c) 2008 QUALCOMM Incorporated.  All rights reserved.
  * The file License.txt specifies the terms for use, modification,
  * and redistribution.
  *
  * Revisions:
  *
+ *     04/18/08  [rcg]
+ *              - guard with # ifndef HAVE_STRLCPY
+ *
  *     06/28/00  [rcg]
  *              - File added.
  *
@@ -34,9 +37,13 @@
 #include "utils.h"
 
 
-
+#ifndef   HAVE_STRLCPY
 size_t strlcpy(char *strdest, const char *strsource, size_t bufsize);
+#endif /* HAVE_STRLCPY */
+#ifndef   HAVE_STRLCAT
 size_t strlcat(char *strdest, const char *strsource, size_t bufsize);
+#endif /* HAVE_STRLCAT */
+
 BOOL   equal_strings(char *str1, long len1, char *str2, long len2);
 char  *string_copy (const char *str, size_t len);
 
